aboutsummaryrefslogtreecommitdiff
path: root/lib/learning-switch.h
diff options
context:
space:
mode:
authorBen Pfaff <blp@nicira.com>2010-12-06 10:03:31 -0800
committerBen Pfaff <blp@nicira.com>2010-12-06 10:03:31 -0800
commitb3907fbc6c74ddad7507d0f7abb1f5a2528cd2be (patch)
treeaf13c768d24cd4d670d8ef19e5793042e9311705 /lib/learning-switch.h
parent772ec52b896380f23b587bea4a5bf18edd22449d (diff)
queue: Get rid of ovs_queue data structure.
ovs_queue doesn't seem very useful; it's just a singly-linked list. It's more generally useful to use a general-purpose "struct list" for lists of packets, so this commit adds such a member to "struct ofpbuf" and shifts the existing users to use it.
Diffstat (limited to 'lib/learning-switch.h')
-rw-r--r--lib/learning-switch.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/learning-switch.h b/lib/learning-switch.h
index d0892576..e5036906 100644
--- a/lib/learning-switch.h
+++ b/lib/learning-switch.h
@@ -41,10 +41,10 @@ struct lswitch_config {
* OFP_FLOW_PERMANENT: Set up permanent flows. */
int max_idle;
- /* Optionally, a chain of one or more OpenFlow messages to send to the
- * switch at time of connection. Presumably these will be OFPT_FLOW_MOD
- * requests to set up the flow table. */
- const struct ofpbuf *default_flows;
+ /* Optionally, a list of one or more "struct ofpbuf"s containing OpenFlow
+ * messages to send to the switch at time of connection. Presumably these
+ * will be OFPT_FLOW_MOD requests to set up the flow table. */
+ const struct list *default_flows;
/* The OpenFlow queue to use by default. Use UINT32_MAX to avoid
* specifying a particular queue. */